@@ -266,7 +266,7 @@ private:
         }// */
     }
 
-    BOOST_SERIALIZATION_SPLIT_MEMBER();
+    BOOST_SERIALIZATION_SPLIT_MEMBER()
 };
 
 
@@ -296,7 +296,7 @@ public:
             QToolButton* pModeAllB,
             QToolButton* pModeAlbumB,
             QToolButton* pModeSongB,
-            bool bUniqueSession);
+            bool bDefaultForVisibleSessBtn);
 
     ~CommonData();
 
@@ -315,6 +315,9 @@ public:
 
     QTableView* m_pUniqueNotesG;
 
+    std::vector<ExternalToolInfo> m_vExternalToolInfos;
+
+
     const std::deque<const Mp3Handler*>& getViewHandlers() const { return m_vpViewHandlers; }
     const std::deque<const Mp3Handler*>& getSelHandlers(); // results are sorted
 
@@ -406,7 +409,7 @@ public:
     // color is normally the category color, but for support notes it's a "support" color; if the note isn't found in vpNoteSet, dGradStart and dGradEnd are set to -1, but normally they get a segment obtained by dividing [0, 1] in equal parts;
     void getNoteColor(const Note& note, const std::vector<const Note*>& vpNoteSet, QColor& color, double& dGradStart, double& dGradEnd) const;
 
-    bool isUniqueSession() const { return m_bUniqueSession; }
+    bool getDefaultForVisibleSessBtn() const { return m_bDefaultForVisibleSessBtn; }
 
     enum { DONT_UPDATE_TRANSFORMS, UPDATE_TRANSFORMS };
     void setFastSave(bool bFastSave, bool bUpdateTransforms);
@@ -418,6 +421,7 @@ public:
 
     bool m_bWarnOnNonSeqTracks, m_bWarnPastingToNonSeqTracks;
     bool m_bShowExport, m_bShowDebug, m_bShowSessions;
+    bool m_bShowCustomCloseButtons;
     bool m_bScanAtStartup;
     std::string m_strNormalizeCmd;
     bool m_bKeepNormWndOpen;
@@ -471,6 +475,7 @@ public:
 
     std::string m_strRenamerInvalidChars;
     std::string m_strRenamerReplacementString;
+    std::string m_strTranslation;
 
 private:
     std::deque<const Mp3Handler*> m_vpAllHandlers; // owns the pointers; sorted by CmpMp3HandlerPtrByName;
@@ -536,7 +541,7 @@ private:
 
     //bool m_bDirty; // seemed like a good idea, but since we also save filters and what's current, pretty much all the time the data will need to be saved
 
-    bool m_bUniqueSession; // if there is a single or several known sessions; if this is false (so there are several sessions) the Sessions button is shown by default
+    bool m_bDefaultForVisibleSessBtn; // the Sessions button is shown by default if there are several sessions
 
     bool m_bFastSave;
     bool m_bTraceToFile;
