@@ -29,6 +29,9 @@
 // Frame of an ID3V2.4.0 tag
 struct Id3V240Frame : public Id3V2Frame
 {
+    Q_DECLARE_TR_FUNCTIONS(Id3V240Frame)
+
+public:
     Id3V240Frame(NoteColl& notes, std::istream& in, std::streampos pos, bool bHasUnsynch, std::streampos posNext, StringWrp* pFileName);
 private:
     bool checkSize(std::istream& in, std::streampos posNext); // since broken applications may use all 8 bits for size, although only 7 should be used, this tries to figure out if the size is correct
@@ -59,11 +62,13 @@ private:
 
 class Id3V240Stream : public Id3V2StreamBase
 {
+    Q_DECLARE_TR_FUNCTIONS(Id3V240Stream)
+
 public:
     Id3V240Stream(int nIndex, NoteColl& notes, std::istream& in, StringWrp* pFileName, bool bAcceptBroken = false);
     //typedef typename Id3V2Stream<Id3V230Frame>::NotId3V2 NotId3V240;
 
-    DECL_RD_NAME("ID3V2.4.0");
+    DECL_RD_NAME("ID3V2.4.0")
 
     /*override*/ TagTimestamp getTime(bool* pbFrameExists = 0) const;
     /*override*/ void setTrackTime(const TagTimestamp&) { throw NotSupportedOp(); }
