@@ -32,6 +32,7 @@
 #include  "OsFile.h"
 #include  "Mp3Manip.h"
 #include  "CommonData.h"
+#include  "Widgets.h"
 
 
 using namespace std;
@@ -204,7 +205,7 @@ TransfConfig::TransfConfig(
 
     if (nOptions >= 0x00040000)
     { // only the first 18 bits are supposed to be used; if more seem to be used, it is because of a manually entered wrong value or because a change in the bitfield representation;
-        QMessageBox::critical(getMainForm(), "Error", "Invalid value found for file settings. Reverting to default settings.");
+        showCritical(getMainForm(), tr("Error"), tr("Invalid value found for file settings. Reverting to default settings."));
         nOptions = -1;
         m_bInitError = true;
     }
@@ -223,7 +224,7 @@ TransfConfig::TransfConfig(
 }
 
 
-TransfConfig::TransfConfig()
+TransfConfig::TransfConfig() : m_bInitError(false)
 {
     m_strSrcDir = getDefaultSrc();
     m_strProcOrigDir = getDefaultProcOrig();
@@ -241,12 +242,15 @@ void TransfConfig::splitOrigName(const string& strOrigSrcName, std::string& strR
 {
 //TRACER1A("splitOrigName ", 1);
 //Tracer t1 (strOrigName);
+    //TRACER1A("splitOrigName ", 1);
+    //TRACER1(strOrigSrcName.c_str(), 2);
     CB_CHECK1 (beginsWith(strOrigSrcName, m_strSrcDir), IncorrectPath());
+    //TRACER1A("splitOrigName ", 3);
 
     strRelDir = strOrigSrcName.substr(m_strSrcDir.size());
 #if defined(WIN32)
     //CB_CHECK1 (beginsWith(strRelDir, getPathSepAsStr()), IncorrectPath()); //ttt2 see if it's OK to skip this test on Windows; it probably is, because it's more of an assert and the fact that it's not triggered on Linux should be enough
-#elif defined(OS2) || defined(__OS2__)
+#elif defined(__OS2__)
     //nothing
 #else
     CB_CHECK1 (beginsWith(strRelDir, getPathSepAsStr()), IncorrectPath());
@@ -264,6 +268,7 @@ void TransfConfig::splitOrigName(const string& strOrigSrcName, std::string& strR
 
     strBaseName = strRelDir.substr(nLastSep + 1);
     strRelDir.erase(nLastSep + 1, string::npos);
+    //TRACER1A("splitOrigName ", 6);
 }
 
 /*
@@ -279,13 +284,18 @@ int TransfConfig::getOptionValue(Option eOption) const
 // adds a counter and/or a label, such that a file with the resulting name doesn't exist;
 /*static*/ string TransfConfig::addLabelAndCounter(const string& s1, const string& s2, const string& strLabel, bool bAlwaysUseCounter, bool bAlwaysRename)
 {
+    //TRACER1A("addLabelAndCounter ", 1);
     string strRes;
     if (!bAlwaysRename)
     {
+        //TRACER1A("addLabelAndCounter ", 2);
         strRes = replaceDriveLetter(s1 + s2);
+        //TRACER1A("addLabelAndCounter ", 3);
         if (!fileExists(strRes))
         {
+            //TRACER1A("addLabelAndCounter ", 4);
             createDirForFile(strRes);
+            //TRACER1A("addLabelAndCounter ", 5);
             return strRes;
         }
     }
@@ -293,34 +303,45 @@ int TransfConfig::getOptionValue(Option eOption) const
     string strLabel2 (strLabel);
     if (!strLabel2.empty()) { strLabel2.insert(0, "."); }
 
+    //TRACER1A("addLabelAndCounter ", 6);
     if (!bAlwaysUseCounter && !strLabel2.empty())
     {
+        //TRACER1A("addLabelAndCounter ", 7);
         strRes = replaceDriveLetter(s1 + strLabel2 + s2);
+        //TRACER1A("addLabelAndCounter ", 8);
         if (!fileExists(strRes))
         {
+            //TRACER1A("addLabelAndCounter ", 9);
             createDirForFile(strRes);
+            //TRACER1A("addLabelAndCounter ", 10);
             return strRes;
         }
     }
+    //TRACER1A("addLabelAndCounter ", 11);
 
     for (int i = 1; ; ++i)
     {
         {
             ostringstream out;
             out << "." << setfill('0') << setw(3) << i;
+            //TRACER1A("addLabelAndCounter ", 12);
             strRes = replaceDriveLetter(s1 + strLabel2 + out.str() + s2);
+            //TRACER1A("addLabelAndCounter ", 13);
         }
 
+        //TRACER1A("addLabelAndCounter ", 14);
         if (!fileExists(strRes))
         {
+            //TRACER1A("addLabelAndCounter ", 15);
             createDirForFile(strRes);
+            //TRACER1A("addLabelAndCounter ", 16);
             return strRes;
         }
     }
 }
 
 // normally makes sure that the name returned doesn't exist, by applying any renaming specified in the params; there's an exception, though: is bAllowDup is true, duplicates are allowed
-string TransfConfig::getRenamedName(const std::string& strOrigSrcName, const std::string& strNewRootDir, const std::string& strLabel, bool bAlwayUseCounter, bool bAlwaysRename, bool bAllowDup /*= false*/) const // bAllowDup is needed only for the option 5 of m_nProcOrigChange, when ORIG_MOVE_OR_ERASE gets returned
+string TransfConfig::getRenamedName(const std::string& strOrigSrcName, const std::string& strNewRootDir, const std::string& strLabel, bool bAlwayUseCounter, bool bAlwaysRename, bool bAllowDup /* = false*/) const // bAllowDup is needed only for the option 5 of m_nProcOrigChange, when ORIG_MOVE_OR_ERASE gets returned
 {
     /* steps
         1. decide if it should rename, based on bAlwaysRename (merely changing the folder isn't considered renaming)
@@ -338,16 +359,21 @@ string TransfConfig::getRenamedName(const std::string& strOrigSrcName, const std
     splitOrigName(strOrigSrcName, strRelDir, strBaseName, strExt);
 
     string strRes;
+    //TRACER1A("getRenamedName ", 2);
 
     if (!bAlwaysRename)
     { // aside from the new folder, no renaming takes places if this new name isn't in use
+        //TRACER1A("getRenamedName ", 3);
         strRes = replaceDriveLetter(strNewRootDir + strRelDir + strBaseName + strExt);
         if (!fileExists(strRes) || bAllowDup)
         {
+            //TRACER1A("getRenamedName ", 4);
             createDirForFile(strRes);
+            //TRACER1A("getRenamedName ", 5);
             return strRes;
         }
     }
+    //TRACER1A("getRenamedName ", 6);
 
     /*if (!bAlwayUseCounter && !strLabel.empty())
     { // now try to use the label but not the counter
@@ -512,8 +538,10 @@ void TransfConfig::testRemoveSuffix() const
 TransfConfig::TransfFile TransfConfig::getProcessedName(string strOrigSrcName, std::string& strName) const
 {
 //TRACER1A("getProcessedName ", 1);
+//Tracer t1 (strOrigSrcName);
     removeSuffix(strOrigSrcName);
     //TRACER1A("getProcessedName ", 2);
+    //Tracer t2 (strOrigSrcName);
     switch (m_options.m_eProcessedCreate)
     {
     case Options::PR_DONT_CREATE: // don't create proc files
@@ -526,6 +554,7 @@ TransfConfig::TransfFile TransfConfig::getProcessedName(string strOrigSrcName, s
         {
             //TRACER1A("getProcessedName ", 4);
             strName = getRenamedName(strOrigSrcName, m_options.m_bProcessedUseSeparateDir ? m_strProcessedDir : m_strSrcDir, m_options.m_bProcessedUseLabel ? "proc" : "", m_options.m_bProcessedAlwayUseCounter, ALWAYS_RENAME);
+            //Tracer t1 (strName);
             return TRANSF_CREATE;
         }
 
@@ -533,6 +562,7 @@ TransfConfig::TransfFile TransfConfig::getProcessedName(string strOrigSrcName, s
         {
             //TRACER1A("getProcessedName ", 5);
             strName = getRenamedName(strOrigSrcName, m_options.m_bProcessedUseSeparateDir ? m_strProcessedDir : m_strSrcDir, m_options.m_bProcessedUseLabel ? "proc" : "", m_options.m_bProcessedAlwayUseCounter, RENAME_IF_NEEDED);
+            //Tracer t1 (strName);
             return TRANSF_CREATE;
         }
 
